==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/logging/adapter/model/internal/adapter/AdapterPackage.java <==
/**********************************************************************
 * Copyright (c) 2003, 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
 
/*
 * generated using Hyades customized JET templates
 */

package org.eclipse.hyades.logging.adapter.model.internal.adapter;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;

/**
 * <!-- begin-user-doc -->
 * The <b>Package</b> for the model.
 * It contains accessors for the meta objects to represent
 * <ul>
 *   <li>each class,</li>
 *   <li>each feature of each class,</li>
 *   <li>each enum,</li>
 *   <li>and each data type</li>
 * </ul>
 * <!-- end-user-doc -->
 * <!-- begin-model-doc -->
 * 
 * 	    Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 	  
 * 
 * 	    Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 	  
 * 
 * 	    Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 	  
 *       Copyright (c) 2003 Hyades
 *             project.   All rights reserved.   This program and the
 *             accompanying materials   are made available under the terms
 *             of the Common Public License v1.0   which accompanies this
 *             distribution, and is available at   http://www.eclipse.org/legal/cpl-v10.html
 *       Copyright (c) 2003 Hyades
 *             project.   All rights reserved.   This program and the
 *             accompanying materials   are made available under the terms
 *             of the Common Public License v1.0   which accompanies this
 *             distribution, and is available at   http://www.eclipse.org/legal/cpl-v10.html
 * 
 * 	    Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 	  
 * 
 * 		Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 			
 * 		This document describes the format for representation of parser rules
 * 		which can be consumed by the generic parser component.
 * 		*********************************************************************
 * 		Change History:
 * 		31 Oct 2003 - Richard K Duggan initial implementation 
 * 		10 Nov 2003 - Richard K Duggan general fixes for id's
 * 		*********************************************************************
 * 		
 * 
 * 	    Copyright (c) 2003 Hyades project.
 * 		All rights reserved.   This program and the accompanying materials
 * 		are made available under the terms of the Common Public License v1.0
 * 		which accompanies this distribution, and is available at
 * 		http://www.eclipse.org/legal/cpl-v10.html
 * 	  
 *       Copyright (c) 2003 Hyades
 *             project.   All rights reserved.   This program and the
 *             accompanying materials   are made available under the terms
 *             of the Common Public License v1.0   which accompanies this
 *             distribution, and is available at   http://www.eclipse.org/legal/cpl-v10.html
 * <!-- end-model-doc -->
 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterFactory
 * @generated
 */
public interface AdapterPackage extends EPackage{
	/**
	 * The package name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNAME = "adapter";

	/**
	 * The package namespace URI.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_URI = "http://www.eclipse.org/hyades/schema/Adapter.xsd";

	/**
	 * The package namespace name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_PREFIX = "adapter";

	/**
	 * The singleton instance of the package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	AdapterPackage eINSTANCE = org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl.init();

	/**
	 * The meta object id for the '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterTypeImpl <em>Type</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterTypeImpl
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl#getAdapterType()
	 * @generated
	 */
	int ADAPTER_TYPE = 0;

	/**
	 * The feature id for the '<em><b>Contexts</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE__CONTEXTS = 0;

	/**
	 * The feature id for the '<em><b>Configuration</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE__CONFIGURATION = 1;

	/**
	 * The number of structural features of the the '<em>Type</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE_FEATURE_COUNT = 2;

	/**
	 * The meta object id for the '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.DocumentRootImpl <em>Document Root</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.DocumentRootImpl
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl#getDocumentRoot()
	 * @generated
	 */
	int DOCUMENT_ROOT = 1;

	/**
	 * The feature id for the '<em><b>Mixed</b></em>' attribute list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__MIXED = 0;

	/**
	 * The feature id for the '<em><b>XMLNS Prefix Map</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__XMLNS_PREFIX_MAP = 1;

	/**
	 * The feature id for the '<em><b>XSI Schema Location</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__XSI_SCHEMA_LOCATION = 2;

	/**
	 * The feature id for the '<em><b>Adapter</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__ADAPTER = 3;

	/**
	 * The number of structural features of the the '<em>Document Root</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT_FEATURE_COUNT = 4;


	/**
	 * Returns the meta object for class '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType <em>Type</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Type</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType
	 * @generated
	 */
	EClass getAdapterType();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getContexts <em>Contexts</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Contexts</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getContexts()
	 * @see #getAdapterType()
	 * @generated
	 */
	EReference getAdapterType_Contexts();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getConfiguration <em>Configuration</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Configuration</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getConfiguration()
	 * @see #getAdapterType()
	 * @generated
	 */
	EReference getAdapterType_Configuration();

	/**
	 * Returns the meta object for class '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot <em>Document Root</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Document Root</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot
	 * @generated
	 */
	EClass getDocumentRoot();

	/**
	 * Returns the meta object for the attribute list '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getMixed <em>Mixed</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute list '<em>Mixed</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getMixed()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EAttribute getDocumentRoot_Mixed();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXMLNSPrefixMap <em>XMLNS Prefix Map</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>XMLNS Prefix Map</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXMLNSPrefixMap()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_XMLNSPrefixMap();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXSISchemaLocation <em>XSI Schema Location</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>XSI Schema Location</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXSISchemaLocation()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_XSISchemaLocation();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getAdapter <em>Adapter</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Adapter</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getAdapter()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_Adapter();

	/**
	 * Returns the factory that creates the instances of the model.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the factory that creates the instances of the model.
	 * @generated
	 */
	AdapterFactory getAdapterFactory();

} //AdapterPackage

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/logging/adapter/model/internal/adapter/AdapterPackage.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 *
 * $Id: AdapterPackage.java,v 1.8 2005/03/24 21:12:26 slavescu Exp $
 **********************************************************************/
 
/*
 * generated using Hyades customized JET templates
 */

package org.eclipse.hyades.logging.adapter.model.internal.adapter;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;

/**
 * <!-- begin-user-doc -->
 * The <b>Package</b> for the model.
 * It contains accessors for the meta objects to represent
 * <ul>
 *   <li>each class,</li>
 *   <li>each feature of each class,</li>
 *   <li>each enum,</li>
 *   <li>and each data type</li>
 * </ul>
 * <!-- end-user-doc -->
 * <!-- begin-model-doc -->
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 	  
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 	  
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 	  
 * 
 *           Copyright (c) 2005 IBM Corporation and others.
 *           All rights reserved.   This program and the accompanying materials
 *           are made available under the terms of the Eclipse Public License v1.0
 *           which accompanies this distribution, and is available at
 *           http://www.eclipse.org/legal/epl-v10.html
 *         
 * 
 *           Copyright (c) 2005 IBM Corporation and others.
 *           All rights reserved.   This program and the accompanying materials
 *           are made available under the terms of the Eclipse Public License v1.0
 *           which accompanies this distribution, and is available at
 *           http://www.eclipse.org/legal/epl-v10.html
 *         
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 	  
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 			
 * 		This document describes the format for representation of parser rules
 * 		which can be consumed by the generic parser component.
 * 		*********************************************************************
 * 		Change History:
 * 		31 Oct 2003 - Richard K Duggan initial implementation 
 * 		10 Nov 2003 - Richard K Duggan general fixes for id's
 * 		*********************************************************************
 * 		
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 	  
 * 
 * 	        Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 * 			
 * 		This document describes the format for representation of filter rules
 * 		which can be consumed by the generic filter component.
 * 		*********************************************************************
 * 		Change History:
 * 		23 Mar 2005 - Dave Smith initial implementation 
 * 		*********************************************************************
 * 		
 * 
 *         Copyright (c) 2005 IBM Corporation and others.
 *         All rights reserved.   This program and the accompanying materials
 *         are made available under the terms of the Eclipse Public License v1.0
 *         which accompanies this distribution, and is available at
 *         http://www.eclipse.org/legal/epl-v10.html
 *       
 * <!-- end-model-doc -->
 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterFactory
 * @generated
 */
public interface AdapterPackage extends EPackage{
	/**
	 * The package name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNAME = "adapter";

	/**
	 * The package namespace URI.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_URI = "http://www.eclipse.org/hyades/schema/Adapter.xsd";

	/**
	 * The package namespace name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_PREFIX = "adapter";

	/**
	 * The singleton instance of the package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	AdapterPackage eINSTANCE = org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl.init();

	/**
	 * The meta object id for the '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterTypeImpl <em>Type</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterTypeImpl
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl#getAdapterType()
	 * @generated
	 */
	int ADAPTER_TYPE = 0;

	/**
	 * The feature id for the '<em><b>Contexts</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE__CONTEXTS = 0;

	/**
	 * The feature id for the '<em><b>Configuration</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE__CONFIGURATION = 1;

	/**
	 * The number of structural features of the the '<em>Type</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADAPTER_TYPE_FEATURE_COUNT = 2;

	/**
	 * The meta object id for the '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.DocumentRootImpl <em>Document Root</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.DocumentRootImpl
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.impl.AdapterPackageImpl#getDocumentRoot()
	 * @generated
	 */
	int DOCUMENT_ROOT = 1;

	/**
	 * The feature id for the '<em><b>Mixed</b></em>' attribute list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__MIXED = 0;

	/**
	 * The feature id for the '<em><b>XMLNS Prefix Map</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__XMLNS_PREFIX_MAP = 1;

	/**
	 * The feature id for the '<em><b>XSI Schema Location</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__XSI_SCHEMA_LOCATION = 2;

	/**
	 * The feature id for the '<em><b>Adapter</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT__ADAPTER = 3;

	/**
	 * The number of structural features of the the '<em>Document Root</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DOCUMENT_ROOT_FEATURE_COUNT = 4;


	/**
	 * Returns the meta object for class '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType <em>Type</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Type</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType
	 * @generated
	 */
	EClass getAdapterType();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getContexts <em>Contexts</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Contexts</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getContexts()
	 * @see #getAdapterType()
	 * @generated
	 */
	EReference getAdapterType_Contexts();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getConfiguration <em>Configuration</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Configuration</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.AdapterType#getConfiguration()
	 * @see #getAdapterType()
	 * @generated
	 */
	EReference getAdapterType_Configuration();

	/**
	 * Returns the meta object for class '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot <em>Document Root</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Document Root</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot
	 * @generated
	 */
	EClass getDocumentRoot();

	/**
	 * Returns the meta object for the attribute list '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getMixed <em>Mixed</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute list '<em>Mixed</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getMixed()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EAttribute getDocumentRoot_Mixed();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXMLNSPrefixMap <em>XMLNS Prefix Map</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>XMLNS Prefix Map</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXMLNSPrefixMap()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_XMLNSPrefixMap();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXSISchemaLocation <em>XSI Schema Location</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>XSI Schema Location</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getXSISchemaLocation()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_XSISchemaLocation();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getAdapter <em>Adapter</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Adapter</em>'.
	 * @see org.eclipse.hyades.logging.adapter.model.internal.adapter.DocumentRoot#getAdapter()
	 * @see #getDocumentRoot()
	 * @generated
	 */
	EReference getDocumentRoot_Adapter();

	/**
	 * Returns the factory that creates the instances of the model.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the factory that creates the instances of the model.
	 * @generated
	 */
	AdapterFactory getAdapterFactory();

} //AdapterPackage
